@@ -1,10 +1,10 @@
 #! /bin/bash -e
-# $Id: jenkins.sh 3485 2014-12-18 14:33:03Z bradbell $
+# $Id: jenkins.sh 3658 2015-02-22 13:56:28Z bradbell $
 # -----------------------------------------------------------------------------
 # CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
-# the terms of the 
+# the terms of the
 #                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
@@ -15,10 +15,14 @@ then
 	echo "bin/jenkins.sh: must be executed from its parent directory"
 	exit 1
 fi
-if [ "$1" != 'none' ] && [ "$1" != 'build' ] && [ "$1" != 'install' ] 
+if [ "$1" != 'none' ] && [ "$1" != 'build' ] && [ "$1" != 'install' ]
 then
 	echo 'bin/junk.sh: redo_external'
-	echo 'Where redo_external is one of: build, install, none' 
+	echo 'where redo_external is one of: build, install, none'
+	echo
+	echo 'build:   download build and install all the externals'
+	echo 'install: reuse as much of previous build as possible'
+	echo 'none:    uses the previous install (fastest option)'
 	exit 1
 fi
 redo_external="$1"
@@ -35,21 +39,21 @@ echo_eval() {
 log_eval() {
 	echo "------------------------------------------------" >> ../jenkins.log
 	echo "------------------------------------------------" >> ../jenkins.err
-	echo $*  >> ../jenkins.log
-	echo $*  >> ../jenkins.err
-	echo $* "1>> ../jenkins.log 2>> ../jenkins.err"
-	if ! eval $*  1>> ../jenkins.log 2>> ../jenkins.err
+	echo $*  >> $trunk_dir/jenkins.log
+	echo $*  >> $trunk_dir/jenkins.err
+	echo $* "1>> $trunk_dir/jenkins.log 2>> $trunk_dir/jenkins.err"
+	if ! eval $*  1>> $trunk_dir/jenkins.log 2>> $trunk_dir/jenkins.err
 	then
-		echo_eval cat ../jenkins.log
-		echo_eval cat ../jenkins.err
+		echo_eval cat $trunk_dir/jenkins.log
+		echo_eval cat $trunk_dir/jenkins.err
 		exit 1
 	fi
 }
 for ext in log err
 do
-	if [ -e "../jenkins.$ext" ]
+	if [ -e "$trunk_dir/jenkins.$ext" ]
 	then
-		echo_eval rm ../jenkins.$ext
+		echo_eval rm $trunk_dir/jenkins.$ext
 	fi
 done
 # --------------------------------------------------------------------------
@@ -67,7 +71,7 @@ if [ "$redo_external" != 'none' ]
 then
 	# -------------------------------------------------------------------
 	# this comand cleans out the previous install for all externals
-	echo_eval rm -rf build/prefix 
+	echo_eval rm -rf build/prefix
 	# -------------------------------------------------------------------
 	if [ "$redo_extrnal" == 'build' ]
 	then
@@ -117,13 +121,13 @@ else
 fi
 # -----------------------------------------------------------------------
 # Use trunk_dir/../build to build and test CppAD (no reuse)
-echo_eval cd ..
-echo_eval rm -rf build
-echo_eval mkdir build
 echo_eval cd build
+echo_eval rm -rf auto_tools
+echo_eval mkdir auto_tools
+echo_eval cd auto_tools
 #
 # configure cppad to use all the packages above
-if which rpm >& /dev/null 
+if which rpm >& /dev/null
 then
 	build_type=`rpm --eval %{_host}`
 	build_type="--build=$build_type"
@@ -160,14 +164,14 @@ then
 fi
 #
 # compile the tests
-log_eval make check 
+log_eval make check
 #
 # run the tests
 log_eval make test
 #
 # print the test results on the console
 echo 'copy make test output to console'
-sed -n -e '/^make test$/,$p' ../jenkins.log
+sed -n -e '/^make test$/,$p' $trunk_dir/jenkins.log
 #
 # make it here without an error exit
 echo "jenkins.sh: OK"
