@@ -1,8 +1,8 @@
-/* $Id: cond_op.hpp 2997 2013-10-27 12:32:25Z bradbell $ */
+/* $Id: cond_op.hpp 3323 2014-09-12 12:10:54Z bradbell $ */
 # ifndef CPPAD_COND_OP_INCLUDED
 # define CPPAD_COND_OP_INCLUDED
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -14,8 +14,6 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 /*!
-\defgroup cond_op_hpp cond_op.hpp
-\{
 \file cond_op.hpp
 Forward, reverse, and sparse operations for conditional expressions.
 */
@@ -87,7 +85,7 @@ is the total number of values in the vector \a parameter.
 For j = 0, 1, 2, 3,
 if y_j is a parameter, \a parameter [ arg[2 + j] ] is its value.
 
-\param nc_taylor
+\param cap_order
 number of columns in the matrix containing the Taylor coefficients.
 
 \par Checked Assertions
@@ -96,7 +94,6 @@ number of columns in the matrix containing the Taylor coefficients.
 \li arg[0] < static_cast<size_t> ( CompareNe )
 \li arg[1] != 0; i.e., not all of y_0, y_1, y_2, y_3 are parameters.
 \li For j = 0, 1, 2, 3 if y_j is a parameter, arg[2+j] < num_par.
-\li For j = 0, 1, 2, 3 if y_j is a variable, arg[2+j] < iz.
 <!-- end conditional_exp_op -->
 */
 template <class Base>
@@ -105,7 +102,7 @@ inline void conditional_exp_op(
 	const addr_t*  arg         , 
 	size_t         num_par     ,
 	const Base*    parameter   ,
-	size_t         nc_taylor   )
+	size_t         cap_order   )
 {	// This routine is only for documentation, it should never be used
 	CPPAD_ASSERT_UNKNOWN( false );
 }
@@ -178,7 +175,6 @@ is the total number of values in the vector \a parameter.
 \li arg[0] < static_cast<size_t> ( CompareNe )
 \li arg[1] != 0; i.e., not all of y_0, y_1, y_2, y_3 are parameters.
 \li For j = 0, 1, 2, 3 if y_j is a parameter, arg[2+j] < num_par.
-\li For j = 0, 1, 2, 3 if y_j is a variable, arg[2+j] < iz.
 <!-- end sparse_conditional_exp_op -->
 */
 template <class Vector_set>
@@ -257,7 +253,7 @@ is the total number of values in the vector \a parameter.
 For j = 0, 1, 2, 3,
 if y_j is a parameter, \a parameter [ arg[2 + j] ] is its value.
 
-\param nc_taylor
+\param cap_order
 number of columns in the matrix containing the Taylor coefficients.
 
 \par Checked Assertions
@@ -266,44 +262,43 @@ number of columns in the matrix containing the Taylor coefficients.
 \li arg[0] < static_cast<size_t> ( CompareNe )
 \li arg[1] != 0; i.e., not all of y_0, y_1, y_2, y_3 are parameters.
 \li For j = 0, 1, 2, 3 if y_j is a parameter, arg[2+j] < num_par.
-\li For j = 0, 1, 2, 3 if y_j is a variable, arg[2+j] < iz.
 <!-- end conditional_exp_op -->
 
-\param q
+\param p
 is the lowest order of the Taylor coefficient of z that we are computing.
 
-\param p
+\param q
 is the highest order of the Taylor coefficient of z that we are computing.
 
 \param taylor
 \b Input:
-For j = 0, 1, 2, 3 and k = 0 , ... , p,
+For j = 0, 1, 2, 3 and k = 0 , ... , q,
 if y_j is a variable then
-<code>taylor [ arg[2+j] * nc_taylor + k ]</code>
+<code>taylor [ arg[2+j] * cap_order + k ]</code>
 is the k-th order Taylor coefficient corresponding to y_j.
 \n
-\b Input: <code>taylor [ i_z * nc_taylor + k ]</code> 
-for k = 0 , ... , q-1,
+\b Input: <code>taylor [ i_z * cap_order + k ]</code> 
+for k = 0 , ... , p-1,
 is the k-th order Taylor coefficient corresponding to z.
 \n
-\b Output: <code>taylor [ i_z * nc_taylor + k ]</code>
-for k = q , ... , p, 
+\b Output: <code>taylor [ i_z * cap_order + k ]</code>
+for k = p , ... , q, 
 is the k-th order Taylor coefficient corresponding to z. 
 
 */
 template <class Base>
 inline void forward_cond_op(
-	size_t         q           ,
 	size_t         p           ,
+	size_t         q           ,
 	size_t         i_z         ,
 	const addr_t*  arg         , 
 	size_t         num_par     ,
 	const Base*    parameter   ,
-	size_t         nc_taylor   ,
+	size_t         cap_order   ,
 	Base*          taylor      )
 {	Base y_0, y_1, y_2, y_3;
 	Base zero(0);
-	Base* z = taylor + i_z * nc_taylor;
+	Base* z = taylor + i_z * cap_order;
 
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < static_cast<size_t> (CompareNe) );
 	CPPAD_ASSERT_UNKNOWN( NumArg(CExpOp) == 6 );
@@ -311,33 +306,33 @@ inline void forward_cond_op(
 	CPPAD_ASSERT_UNKNOWN( arg[1] != 0 );
 
 	if( arg[1] & 1 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < i_z );
-		y_0 = taylor[ arg[2] * nc_taylor + 0 ];
+	{
+		y_0 = taylor[ arg[2] * cap_order + 0 ];
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < num_par );
 		y_0 = parameter[ arg[2] ];
 	}
 	if( arg[1] & 2 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < i_z );
-		y_1 = taylor[ arg[3] * nc_taylor + 0 ];
+	{
+		y_1 = taylor[ arg[3] * cap_order + 0 ];
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < num_par );
 		y_1 = parameter[ arg[3] ];
 	}
-	if( q == 0 )
+	if( p == 0 )
 	{	if( arg[1] & 4 )
-		{	CPPAD_ASSERT_UNKNOWN( size_t(arg[4]) < i_z );
-			y_2 = taylor[ arg[4] * nc_taylor + 0 ];
+		{
+			y_2 = taylor[ arg[4] * cap_order + 0 ];
 		}
 		else
 		{	CPPAD_ASSERT_UNKNOWN( size_t(arg[4]) < num_par );
 			y_2 = parameter[ arg[4] ];
 		}
 		if( arg[1] & 8 )
-		{	CPPAD_ASSERT_UNKNOWN( size_t(arg[5]) < i_z );
-			y_3 = taylor[ arg[5] * nc_taylor + 0 ];
+		{
+			y_3 = taylor[ arg[5] * cap_order + 0 ];
 		}
 		else
 		{	CPPAD_ASSERT_UNKNOWN( size_t(arg[5]) < num_par );
@@ -350,17 +345,17 @@ inline void forward_cond_op(
 			y_2,
 			y_3
 		);
-		q++;
+		p++;
 	}
-	for(size_t d = q; d <= p; d++)
+	for(size_t d = p; d <= q; d++)
 	{	if( arg[1] & 4 )
-		{	CPPAD_ASSERT_UNKNOWN( size_t(arg[4]) < i_z );
-			y_2 = taylor[ arg[4] * nc_taylor + d];
+		{
+			y_2 = taylor[ arg[4] * cap_order + d];
 		}
 		else	y_2 = zero;
 		if( arg[1] & 8 )
-		{	CPPAD_ASSERT_UNKNOWN( size_t(arg[5]) < i_z );
-			y_3 = taylor[ arg[5] * nc_taylor + d];
+		{
+			y_3 = taylor[ arg[5] * cap_order + d];
 		}
 		else	y_3 = zero;
 		z[d] = CondExpOp(
@@ -374,6 +369,176 @@ inline void forward_cond_op(
 	return;
 }
 
+/*!
+Multiple directions forward mode Taylor coefficients for op = CExpOp.
+
+<!-- replace conditional_exp_op -->
+The C++ source code coresponding to this operation is
+\verbatim
+	z = CondExpRel(y_0, y_1, y_2, y_3)
+\endverbatim
+where Rel is one of the following: Lt, Le, Eq, Ge, Gt. 
+
+\tparam Base
+base type for the operator; i.e., this operation was recorded
+using AD< \a Base > and computations by this routine are done using type 
+\a Base.
+
+\param i_z
+is the AD variable index corresponding to the variable z.
+
+\param arg
+\n
+\a arg[0]
+is static cast to size_t from the enum type
+\verbatim
+	enum CompareOp {
+		CompareLt, 
+		CompareLe, 
+		CompareEq, 
+		CompareGe, 
+		CompareGt, 
+		CompareNe
+	}
+\endverbatim
+for this operation.
+Note that arg[0] cannot be equal to CompareNe.
+\n
+\n
+\a arg[1] & 1
+\n
+If this is zero, y_0 is a parameter. Otherwise it is a variable.
+\n
+\n
+\a arg[1] & 2
+\n
+If this is zero, y_1 is a parameter. Otherwise it is a variable.
+\n
+\n
+\a arg[1] & 4
+\n
+If this is zero, y_2 is a parameter. Otherwise it is a variable.
+\n
+\n
+\a arg[1] & 8
+\n
+If this is zero, y_3 is a parameter. Otherwise it is a variable.
+\n
+\n
+\a arg[2 + j ] for j = 0, 1, 2, 3
+\n
+is the index corresponding to y_j.
+
+\param num_par
+is the total number of values in the vector \a parameter.
+
+\param parameter
+For j = 0, 1, 2, 3,
+if y_j is a parameter, \a parameter [ arg[2 + j] ] is its value.
+
+\param cap_order
+number of columns in the matrix containing the Taylor coefficients.
+
+\par Checked Assertions
+\li NumArg(CExpOp) == 6
+\li NumRes(CExpOp) == 1
+\li arg[0] < static_cast<size_t> ( CompareNe )
+\li arg[1] != 0; i.e., not all of y_0, y_1, y_2, y_3 are parameters.
+\li For j = 0, 1, 2, 3 if y_j is a parameter, arg[2+j] < num_par.
+<!-- end conditional_exp_op -->
+
+\param q
+is order of the Taylor coefficient of z that we are computing.
+
+\param r
+is the number of Taylor coefficient directions that we are computing.
+
+\par tpv
+We use the notation
+<code>tpv = (cap_order-1) * r + 1</code>
+which is the number of Taylor coefficients per variable
+
+\param taylor
+\b Input:
+For j = 0, 1, 2, 3, k = 1, ..., q,
+if y_j is a variable then
+<code>taylor [ arg[2+j] * tpv + 0 ]</code>
+is the zero order Taylor coefficient corresponding to y_j and
+<code>taylor [ arg[2+j] * tpv + (k-1)*r+1+ell</code> is its
+k-th order Taylor coefficient in the ell-th direction.
+\n
+\b Input: 
+For j = 0, 1, 2, 3, k = 1, ..., q-1,
+<code>taylor [ i_z * tpv + 0 ]</code> 
+is the zero order Taylor coefficient corresponding to z and
+<code>taylor [ i_z * tpv + (k-1)*r+1+ell</code> is its
+k-th order Taylor coefficient in the ell-th direction.
+\n
+\b Output: <code>taylor [ i_z * tpv + (q-1)*r+1+ell ]</code>
+is the q-th order Taylor coefficient corresponding to z
+in the ell-th direction. 
+*/
+template <class Base>
+inline void forward_cond_op_dir(
+	size_t         q           ,
+	size_t         r           ,
+	size_t         i_z         ,
+	const addr_t*  arg         , 
+	size_t         num_par     ,
+	const Base*    parameter   ,
+	size_t         cap_order   ,
+	Base*          taylor      )
+{	Base y_0, y_1, y_2, y_3;
+	Base zero(0);
+	size_t num_taylor_per_var = (cap_order-1) * r + 1;
+	Base* z = taylor + i_z * num_taylor_per_var;
+
+	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < static_cast<size_t> (CompareNe) );
+	CPPAD_ASSERT_UNKNOWN( NumArg(CExpOp) == 6 );
+	CPPAD_ASSERT_UNKNOWN( NumRes(CExpOp) == 1 );
+	CPPAD_ASSERT_UNKNOWN( arg[1] != 0 );
+	CPPAD_ASSERT_UNKNOWN( 0 < q );
+	CPPAD_ASSERT_UNKNOWN( q < cap_order );
+
+	if( arg[1] & 1 )
+	{
+		y_0 = taylor[ arg[2] * num_taylor_per_var + 0 ];
+	}
+	else
+	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < num_par );
+		y_0 = parameter[ arg[2] ];
+	}
+	if( arg[1] & 2 )
+	{
+		y_1 = taylor[ arg[3] * num_taylor_per_var + 0 ];
+	}
+	else
+	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < num_par );
+		y_1 = parameter[ arg[3] ];
+	}
+	size_t m = (q-1) * r + 1;
+	for(size_t ell = 0; ell < r; ell++)
+	{	if( arg[1] & 4 )
+		{
+			y_2 = taylor[ arg[4] * num_taylor_per_var + m + ell];
+		}
+		else	y_2 = zero;
+		if( arg[1] & 8 )
+		{
+			y_3 = taylor[ arg[5] * num_taylor_per_var + m + ell];
+		}
+		else	y_3 = zero;
+		z[m+ell] = CondExpOp(
+			CompareOp( arg[0] ),
+			y_0,
+			y_1,
+			y_2,
+			y_3
+		);
+	}
+	return;
+}
+
 /*!
 Compute zero order forward mode Taylor coefficients for op = CExpOp.
 
@@ -441,7 +606,7 @@ is the total number of values in the vector \a parameter.
 For j = 0, 1, 2, 3,
 if y_j is a parameter, \a parameter [ arg[2 + j] ] is its value.
 
-\param nc_taylor
+\param cap_order
 number of columns in the matrix containing the Taylor coefficients.
 
 \par Checked Assertions
@@ -450,17 +615,16 @@ number of columns in the matrix containing the Taylor coefficients.
 \li arg[0] < static_cast<size_t> ( CompareNe )
 \li arg[1] != 0; i.e., not all of y_0, y_1, y_2, y_3 are parameters.
 \li For j = 0, 1, 2, 3 if y_j is a parameter, arg[2+j] < num_par.
-\li For j = 0, 1, 2, 3 if y_j is a variable, arg[2+j] < iz.
 <!-- end conditional_exp_op -->
 
 \param taylor
 \b Input:
 For j = 0, 1, 2, 3,
 if y_j is a variable then
-\a taylor [ \a arg[2+j] * nc_taylor + 0 ]
+\a taylor [ \a arg[2+j] * cap_order + 0 ]
 is the zero order Taylor coefficient corresponding to y_j.
 \n
-\b Output: \a taylor [ \a i_z * \a nc_taylor + 0 ] 
+\b Output: \a taylor [ \a i_z * \a cap_order + 0 ] 
 is the zero order Taylor coefficient corresponding to z. 
 */
 template <class Base>
@@ -469,7 +633,7 @@ inline void forward_cond_op_0(
 	const addr_t*  arg         , 
 	size_t         num_par     ,
 	const Base*    parameter   ,
-	size_t         nc_taylor   ,
+	size_t         cap_order   ,
 	Base*          taylor      )
 {	Base y_0, y_1, y_2, y_3;
 	Base* z;
@@ -480,38 +644,38 @@ inline void forward_cond_op_0(
 	CPPAD_ASSERT_UNKNOWN( arg[1] != 0 );
 
 	if( arg[1] & 1 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < i_z );
-		y_0 = taylor[ arg[2] * nc_taylor + 0 ];
+	{
+		y_0 = taylor[ arg[2] * cap_order + 0 ];
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < num_par );
 		y_0 = parameter[ arg[2] ];
 	}
 	if( arg[1] & 2 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < i_z );
-		y_1 = taylor[ arg[3] * nc_taylor + 0 ];
+	{
+		y_1 = taylor[ arg[3] * cap_order + 0 ];
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < num_par );
 		y_1 = parameter[ arg[3] ];
 	}
 	if( arg[1] & 4 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[4]) < i_z );
-		y_2 = taylor[ arg[4] * nc_taylor + 0 ];
+	{
+		y_2 = taylor[ arg[4] * cap_order + 0 ];
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[4]) < num_par );
 		y_2 = parameter[ arg[4] ];
 	}
 	if( arg[1] & 8 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[5]) < i_z );
-		y_3 = taylor[ arg[5] * nc_taylor + 0 ];
+	{
+		y_3 = taylor[ arg[5] * cap_order + 0 ];
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[5]) < num_par );
 		y_3 = parameter[ arg[5] ];
 	}
-	z = taylor + i_z * nc_taylor;
+	z = taylor + i_z * cap_order;
 	z[0] = CondExpOp(
 		CompareOp( arg[0] ),
 		y_0,
@@ -597,7 +761,7 @@ is the total number of values in the vector \a parameter.
 For j = 0, 1, 2, 3,
 if y_j is a parameter, \a parameter [ arg[2 + j] ] is its value.
 
-\param nc_taylor
+\param cap_order
 number of columns in the matrix containing the Taylor coefficients.
 
 \par Checked Assertions
@@ -606,7 +770,6 @@ number of columns in the matrix containing the Taylor coefficients.
 \li arg[0] < static_cast<size_t> ( CompareNe )
 \li arg[1] != 0; i.e., not all of y_0, y_1, y_2, y_3 are parameters.
 \li For j = 0, 1, 2, 3 if y_j is a parameter, arg[2+j] < num_par.
-\li For j = 0, 1, 2, 3 if y_j is a variable, arg[2+j] < iz.
 <!-- end conditional_exp_op -->
 
 \param d
@@ -616,10 +779,10 @@ is the order of the Taylor coefficient of z that we are  computing.
 \b Input:
 For j = 0, 1, 2, 3 and k = 0 , ... , \a d,
 if y_j is a variable then
-\a taylor [ \a arg[2+j] * nc_taylor + k ]
+\a taylor [ \a arg[2+j] * cap_order + k ]
 is the k-th order Taylor coefficient corresponding to y_j.
 \n
-\a taylor [ \a i_z * \a nc_taylor + k ] 
+\a taylor [ \a i_z * \a cap_order + k ] 
 for k = 0 , ... , \a d
 is the k-th order Taylor coefficient corresponding to z.
 
@@ -634,7 +797,7 @@ if y_j is a variable then
 is the partial derivative of G( z , y , x , w , u , ... )
 with respect to the k-th order Taylor coefficient corresponding to y_j.
 \n
-\b Input: \a partial [ \a i_z * \a nc_taylor + k ] 
+\b Input: \a partial [ \a i_z * \a cap_order + k ] 
 for k = 0 , ... , \a d
 is the partial derivative of G( z , y , x , w , u , ... )
 with respect to the k-th order Taylor coefficient corresponding to z.
@@ -654,7 +817,7 @@ inline void reverse_cond_op(
 	const addr_t*  arg         , 
 	size_t         num_par     ,
 	const Base*    parameter   ,
-	size_t         nc_taylor   ,
+	size_t         cap_order   ,
 	const Base*    taylor      ,
 	size_t         nc_partial  ,
 	Base*          partial     )
@@ -671,23 +834,23 @@ inline void reverse_cond_op(
 
 	pz = partial + i_z * nc_partial + 0;
 	if( arg[1] & 1 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < i_z );
-		y_0 = taylor[ arg[2] * nc_taylor + 0 ];
+	{
+		y_0 = taylor[ arg[2] * cap_order + 0 ];
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < num_par );
 		y_0 = parameter[ arg[2] ];
 	}
 	if( arg[1] & 2 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < i_z );
-		y_1 = taylor[ arg[3] * nc_taylor + 0 ];
+	{
+		y_1 = taylor[ arg[3] * cap_order + 0 ];
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < num_par );
 		y_1 = parameter[ arg[3] ];
 	}
 	if( arg[1] & 4 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[4]) < i_z );
+	{
 		py_2 = partial + arg[4] * nc_partial;
 		size_t j = d + 1;
 		while(j--)
@@ -701,7 +864,7 @@ inline void reverse_cond_op(
 		}
 	}
 	if( arg[1] & 8 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[5]) < i_z );
+	{
 		py_3 = partial + arg[5] * nc_partial;
 		size_t j = d + 1;
 		while(j--)
@@ -785,7 +948,6 @@ is the total number of values in the vector \a parameter.
 \li arg[0] < static_cast<size_t> ( CompareNe )
 \li arg[1] != 0; i.e., not all of y_0, y_1, y_2, y_3 are parameters.
 \li For j = 0, 1, 2, 3 if y_j is a parameter, arg[2+j] < num_par.
-\li For j = 0, 1, 2, 3 if y_j is a variable, arg[2+j] < iz.
 <!-- end sparse_conditional_exp_op -->
 
 \param sparsity
@@ -821,22 +983,22 @@ inline void forward_sparse_jacobian_cond_op(
 
 # ifndef NDEBUG
 	if( arg[1] & 1 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < i_z );
+	{
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < num_par );
 	}
 	if( arg[1] & 2 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < i_z );
+	{
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < num_par );
 	}
 # endif
 	if( arg[1] & 4 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[4]) < i_z );
+	{
 		if( arg[1] & 8 )
-		{	CPPAD_ASSERT_UNKNOWN( size_t(arg[5]) < i_z );
+		{
 			sparsity.binary_union(i_z, arg[4], arg[5], sparsity);
 		}
 		else
@@ -847,7 +1009,7 @@ inline void forward_sparse_jacobian_cond_op(
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[4]) < num_par );
 		if( arg[1] & 8 )
-		{	CPPAD_ASSERT_UNKNOWN( size_t(arg[5]) < i_z );
+		{
 			sparsity.assignment(i_z, arg[5], sparsity);
 		}
 		else
@@ -934,7 +1096,6 @@ is the total number of values in the vector \a parameter.
 \li arg[0] < static_cast<size_t> ( CompareNe )
 \li arg[1] != 0; i.e., not all of y_0, y_1, y_2, y_3 are parameters.
 \li For j = 0, 1, 2, 3 if y_j is a parameter, arg[2+j] < num_par.
-\li For j = 0, 1, 2, 3 if y_j is a variable, arg[2+j] < iz.
 <!-- end sparse_conditional_exp_op -->
 
 \param nz_compare
@@ -981,13 +1142,13 @@ inline void reverse_sparse_jacobian_cond_op(
 
 # ifndef NDEBUG
 	if( arg[1] & 1 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < i_z );
+	{
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < num_par );
 	}
 	if( arg[1] & 2 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < i_z );
+	{
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < num_par );
@@ -1001,21 +1162,21 @@ inline void reverse_sparse_jacobian_cond_op(
 # endif
 	if( nz_compare )
 	{	if( arg[1] & 1 )
-		{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < i_z );
+		{
 			sparsity.binary_union(arg[2], arg[2], i_z, sparsity);
 		}
 		if( arg[1] & 2 )
-		{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < i_z );
+		{
 			sparsity.binary_union(arg[3], arg[3], i_z, sparsity);
 		}
 	}
 	// --------------------------------------------------------------------
 	if( arg[1] & 4 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[4]) < i_z );
+	{
 		sparsity.binary_union(arg[4], arg[4], i_z, sparsity);
 	}
 	if( arg[1] & 8 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[5]) < i_z );
+	{
 		sparsity.binary_union(arg[5], arg[5], i_z, sparsity);
 	}
 	return;
@@ -1097,7 +1258,6 @@ is the total number of values in the vector \a parameter.
 \li arg[0] < static_cast<size_t> ( CompareNe )
 \li arg[1] != 0; i.e., not all of y_0, y_1, y_2, y_3 are parameters.
 \li For j = 0, 1, 2, 3 if y_j is a parameter, arg[2+j] < num_par.
-\li For j = 0, 1, 2, 3 if y_j is a variable, arg[2+j] < iz.
 <!-- end sparse_conditional_exp_op -->
 
 
@@ -1161,13 +1321,13 @@ inline void reverse_sparse_hessian_cond_op(
 
 # ifndef NDEBUG
 	if( arg[1] & 1 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < i_z );
+	{
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < num_par );
 	}
 	if( arg[1] & 2 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < i_z );
+	{
 	}
 	else
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[3]) < num_par );
@@ -1180,13 +1340,13 @@ inline void reverse_sparse_hessian_cond_op(
 	}
 # endif
 	if( arg[1] & 4 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[4]) < i_z );
+	{
 
 		hes_sparsity.binary_union(arg[4], arg[4], i_z, hes_sparsity);
 		jac_reverse[ arg[4] ] |= jac_reverse[i_z];
 	}
 	if( arg[1] & 8 )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[5]) < i_z );
+	{
 
 		hes_sparsity.binary_union(arg[5], arg[5], i_z, hes_sparsity);
 		jac_reverse[ arg[5] ] |= jac_reverse[i_z];
@@ -1194,6 +1354,5 @@ inline void reverse_sparse_hessian_cond_op(
 	return;
 }
 
-/*! \} */
 } // END_CPPAD_NAMESPACE
 # endif
