@@ -1,4 +1,4 @@
-/* $Id: optimize.hpp 3507 2014-12-27 16:30:12Z bradbell $ */
+/* $Id: optimize.hpp 3643 2015-02-12 11:47:46Z bradbell $ */
 # ifndef CPPAD_OPTIMIZE_INCLUDED
 # define CPPAD_OPTIMIZE_INCLUDED
 
@@ -1415,6 +1415,7 @@ void optimize_run(
 			case CosOp:
 			case CoshOp:
 			case DivvpOp:
+			case ErfOp:
 			case ExpOp:
 			case LogOp:
 			case PowvpOp:
@@ -2174,6 +2175,23 @@ void optimize_run(
 				CPPAD_ASSERT_UNKNOWN( size_t(new_arg[0]) < i );
 			}
 			break;
+
+			case ErfOp:
+			// 20150000 version does not optimzie this out
+			// next years version does.
+			{	CPPAD_ASSERT_UNKNOWN( NumArg(ErfOp) == 3 );
+				// second argument is always parameter 0
+				// third argument is always parameter 2 / sqrt(pi)
+				tape[i_var].new_op  = rec->num_op_rec();
+				tape[i_var].new_var = rec->PutOp(op);
+				rec->PutArg( tape[ arg[0] ].new_var );
+				rec->PutArg( rec->PutPar( Base(0) ) );
+				rec->PutArg( rec->PutPar( 
+					Base( 1.0 / std::sqrt( std::atan(1.0) ) )
+				) );
+			}
+			break;
+
 			// ---------------------------------------------------
 			// Binary operators where 
 			// left is a variable and right is a parameter
@@ -2248,7 +2266,7 @@ void optimize_run(
 				tape[i_var].new_op  = rec->num_op_rec();
 				tape[i_var].new_var = rec->PutOp(op);
 				CPPAD_ASSERT_UNKNOWN( 
-					size_t(new_arg[1]) < tape[i_var].new_var
+					new_arg[1] < tape[i_var].new_var
 				);
 				replace_hash = true;
 			}
@@ -2650,7 +2668,7 @@ void optimize_run(
 			{	i_var = info.skip_var_true[j];
 				if( tape[i_var].match )
 				{	// the operation for this argument has been removed
-					rec->ReplaceArg(i_arg++, 0);
+					rec->ReplaceArg(i_arg++, rec->num_op_rec());
 				}
 				else
 				{	CPPAD_ASSERT_UNKNOWN( tape[i_var].new_op > 0 );
@@ -2665,7 +2683,7 @@ void optimize_run(
 			{	i_var = info.skip_var_false[j];
 				if( tape[i_var].match )
 				{	// the operation for this argument has been removed
-					rec->ReplaceArg(i_arg++, 0);
+					rec->ReplaceArg(i_arg++, rec->num_op_rec());
 				}
 				else
 				{	CPPAD_ASSERT_UNKNOWN( tape[i_var].new_op > 0 );
