@@ -1,12 +1,12 @@
-/* $Id: rev_jac_sweep.hpp 2994 2013-10-23 15:47:20Z bradbell $ */
+/* $Id: rev_jac_sweep.hpp 3495 2014-12-24 01:16:15Z bradbell $ */
 # ifndef CPPAD_REV_JAC_SWEEP_INCLUDED
 # define CPPAD_REV_JAC_SWEEP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -15,15 +15,13 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 /*!
-\defgroup rev_jac_sweep_hpp rev_jac_sweep.hpp
-\{
 \file rev_jac_sweep.hpp
 Compute Reverse mode Jacobian sparsity patterns.
 */
 
 /*!
 \def CPPAD_REV_JAC_SWEEP_TRACE
-This value is either zero or one. 
+This value is either zero or one.
 Zero is the normal operational value.
 If it is one, a trace of every rev_jac_sweep computation is printed.
 */
@@ -40,7 +38,7 @@ otherwise, it respolves to
 \code
 	user_ok = user_atom->rev_sparse_jac
 \endcode
-This maco is undefined at the end of this file to facillitate is 
+This maco is undefined at the end of this file to facillitate is
 use with a different definition in other files.
 */
 # ifdef NDEBUG
@@ -55,7 +53,7 @@ RevJacSweep computes the sparsity pattern for all the independent variables.
 
 \tparam Base
 base type for the operator; i.e., this operation sequence was recorded
-using AD< \a Base > and computations by this routine are done using type 
+using AD< \a Base > and computations by this routine are done using type
 \a Base.
 
 \tparam Vector_set
@@ -75,7 +73,7 @@ is the number of independent variables on the tape.
 
 \param numvar
 is the total number of variables on the tape; i.e.,
-\a play->num_rec_var().
+\a play->num_var_rec().
 This is also the number of rows in the entire sparsity pattern \a RevJac.
 
 \param play
@@ -98,15 +96,15 @@ the forward Jacobian sparsity pattern for variable i
 corresponds to the set with index i in \a var_sparsity.
 \b
 \b
-\b Input: 
+\b Input:
 For i = 0 , ... , \a numvar - 1,
 the forward Jacobian sparsity pattern for variable i is an input
 if i corresponds to a dependent variable.
-Otherwise the sparsity patten is empty. 
+Otherwise the sparsity patten is empty.
 \n
 \n
 \b Output: For j = 1 , ... , \a n,
-the sparsity pattern for the dependent variable with index (j-1) 
+the sparsity pattern for the dependent variable with index (j-1)
 is given by the set with index index j in \a var_sparsity.
 */
 
@@ -128,21 +126,21 @@ void RevJacSweep(
 	size_t            i, j, k;
 
 	// length of the parameter vector (used by CppAD assert macros)
-	const size_t num_par = play->num_rec_par();
+	const size_t num_par = play->num_par_rec();
 
 	// check numvar argument
 	CPPAD_ASSERT_UNKNOWN( numvar > 0 );
-	CPPAD_ASSERT_UNKNOWN( play->num_rec_var()   == numvar );
+	CPPAD_ASSERT_UNKNOWN( play->num_var_rec()   == numvar );
 	CPPAD_ASSERT_UNKNOWN( var_sparsity.n_set() == numvar );
 
 	// upper limit (exclusive) for elements in the set
 	size_t limit = var_sparsity.end();
 
 	// vecad_sparsity contains a sparsity pattern for each VecAD object.
-	// vecad_ind maps a VecAD index (beginning of the VecAD object) 
-	// to the index of the corresponding set in vecad_sparsity. 
-	size_t num_vecad_ind   = play->num_rec_vecad_ind();
-	size_t num_vecad_vec   = play->num_rec_vecad_vec();
+	// vecad_ind maps a VecAD index (beginning of the VecAD object)
+	// to the index of the corresponding set in vecad_sparsity.
+	size_t num_vecad_ind   = play->num_vec_ind_rec();
+	size_t num_vecad_vec   = play->num_vecad_vec_rec();
 	Vector_set  vecad_sparsity;
 	vecad_sparsity.resize(num_vecad_vec, limit);
 	pod_vector<size_t> vecad_ind;
@@ -154,13 +152,13 @@ void RevJacSweep(
 		{	// length of this VecAD
 			length   = play->GetVecInd(j);
 			// set to proper index for this VecAD
-			vecad_ind[j] = i; 
+			vecad_ind[j] = i;
 			for(k = 1; k <= length; k++)
 				vecad_ind[j+k] = num_vecad_vec; // invalid index
 			// start of next VecAD
 			j       += length + 1;
 		}
-		CPPAD_ASSERT_UNKNOWN( j == play->num_rec_vecad_ind() );
+		CPPAD_ASSERT_UNKNOWN( j == play->num_vec_ind_rec() );
 	}
 
 	// work space used by UserOp.
@@ -190,17 +188,17 @@ void RevJacSweep(
 	enum { user_start, user_arg, user_ret, user_end } user_state = user_end;
 
 	// Initialize
-	play->start_reverse(op, arg, i_op, i_var);
+	play->reverse_start(op, arg, i_op, i_var);
 	CPPAD_ASSERT_UNKNOWN( op == EndOp );
 # if CPPAD_REV_JAC_SWEEP_TRACE
 	std::cout << std::endl;
-	CppAD::vector<bool> z_value(limit);
+	CppAD::vectorBool z_value(limit);
 # endif
 	bool more_operators = true;
 	while(more_operators)
 	{
 		// next op
-		play->next_reverse(op, arg, i_op, i_var);
+		play->reverse_next(op, arg, i_op, i_var);
 # ifndef NDEBUG
 		if( i_op <= n )
 		{	CPPAD_ASSERT_UNKNOWN((op == InvOp) | (op == BeginOp));
@@ -270,16 +268,16 @@ void RevJacSweep(
 
 			case CSkipOp:
 			// CSkipOp has a variable number of arguments and
-			// next_reverse thinks it one has one argument.
-			// We must inform next_reverse of this special case.
+			// reverse_next thinks it one has one argument.
+			// We must inform reverse_next of this special case.
 			play->reverse_cskip(op, arg, i_op, i_var);
 			break;
 			// -------------------------------------------------
 
 			case CSumOp:
 			// CSumOp has a variable number of arguments and
-			// next_reverse thinks it one has one argument.
-			// We must inform next_reverse of this special case.
+			// reverse_next thinks it one has one argument.
+			// We must inform reverse_next of this special case.
 			play->reverse_csum(op, arg, i_op, i_var);
 			reverse_sparse_jacobian_csum_op(
 				i_var, arg, var_sparsity
@@ -348,6 +346,14 @@ void RevJacSweep(
 			break;
 			// -------------------------------------------------
 
+			case ErfOp:
+			CPPAD_ASSERT_NARG_NRES(op, 1, 1);
+			reverse_sparse_jacobian_unary_op(
+				i_var, arg[0], var_sparsity
+			);
+			break;
+			// -------------------------------------------------
+
 			case ExpOp:
 			CPPAD_ASSERT_NARG_NRES(op, 1, 1);
 			reverse_sparse_jacobian_unary_op(
@@ -566,7 +572,7 @@ void RevJacSweep(
 				user_atom  = atomic_base<Base>::class_object(user_index);
 # ifndef NDEBUG
 				if( user_atom == CPPAD_NULL )
-				{	std::string msg = 
+				{	std::string msg =
 						atomic_base<Base>::class_name(user_index)
 						+ ": atomic_base function has been deleted";
 					CPPAD_ASSERT_KNOWN(false, msg.c_str() );
@@ -603,7 +609,7 @@ void RevJacSweep(
 				CPPAD_ASSERT_UNKNOWN( user_m     == size_t(arg[3]) );
 # ifndef NDEBUG
 				if( ! user_ok )
-				{	std::string msg = 
+				{	std::string msg =
 						atomic_base<Base>::class_name(user_index)
 						+ ": atomic_base.rev_sparse_jac: returned false";
 					CPPAD_ASSERT_KNOWN(false, msg.c_str() );
@@ -659,7 +665,7 @@ void RevJacSweep(
 			if( user_i == 0 )
 			{	// call users function for this operation
 				user_atom->set_id(user_id);
-				if( user_bool) 
+				if( user_bool)
 					CPPAD_ATOMIC_CALL(
 						user_q, bool_r, bool_s
 				);
@@ -688,7 +694,7 @@ void RevJacSweep(
 			if( user_i == 0 )
 			{	// call users function for this operation
 				user_atom->set_id(user_id);
-				if( user_bool) 
+				if( user_bool)
 					CPPAD_ATOMIC_CALL(
 						user_q, bool_r, bool_s
 				);
@@ -714,26 +720,32 @@ void RevJacSweep(
 			j          = var_sparsity.next_element();
 		}
 		printOp(
-			std::cout, 
+			std::cout,
 			play,
 			i_op,
 			i_var,
-			op, 
-			arg,
-			0, 
-			(CppAD::vector<bool> *) CPPAD_NULL,
-			1, 
+			op,
+			arg
+		);
+		if( NumRes(op) > 0 && op != BeginOp ) printOpResult(
+			std::cout,
+			0,
+			(CppAD::vectorBool *) CPPAD_NULL,
+			1,
 			&z_value
 		);
-# endif
+		std::cout << std::endl;
 	}
+	std::cout << std::endl;
+# else
+	}
+# endif
 	// values corresponding to BeginOp
 	CPPAD_ASSERT_UNKNOWN( i_op == 0 );
 	CPPAD_ASSERT_UNKNOWN( i_var == 0 );
 
 	return;
 }
-/*! \} */
 } // END_CPPAD_NAMESPACE
 
 // preprocessor symbols that are local to this file
