@@ -1,9 +1,9 @@
-/* $Id: sparse_hessian.hpp 2910 2013-10-07 13:27:58Z bradbell $ */
+/* $Id: sparse_hessian.hpp 3239 2014-04-28 23:00:17Z bradbell $ */
 # ifndef CPPAD_SPARSE_HESSIAN_INCLUDED
 # define CPPAD_SPARSE_HESSIAN_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
@@ -246,8 +246,6 @@ $end
 
 namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 /*!
-\defgroup sparse_hessian_hpp sparse_hessian.hpp
-\{
 \file sparse_hessian.hpp
 Sparse Hessian driver routine and helper functions.
 */
@@ -258,19 +256,13 @@ so it does not need to be recomputed.
 */
 class sparse_hessian_work {
 	public:
-		/// version of user r array sorted by row or column
-		CppAD::vector<size_t> r_sort;
-		/// version of user c array sorted by row or column
-		CppAD::vector<size_t> c_sort;
-		/// mapping from sorted array indices to user array indices
-		CppAD::vector<size_t> k_sort;
+		/// indices that sort the user row and col arrays by color
+		CppAD::vector<size_t> order;
 		/// results of the coloring algorithm
 		CppAD::vector<size_t> color;
 		/// inform CppAD that this information needs to be recomputed
 		void clear(void)
-		{	r_sort.clear();
-			c_sort.clear();
-			k_sort.clear();
+		{	order.clear();
 			color.clear();
 		}
 };
@@ -279,50 +271,73 @@ class sparse_hessian_work {
 Private helper function that does computation for all Sparse Hessian cases.
 
 \tparam Base
-See \c SparseHessian(x, w, p, row, col, hes, work).
+is the base type for the recording that is stored in this ADFun<Base object.
 
 \tparam VectorBase
-See \c SparseHessian(x, w, p, row, col, hes, work).
+is a simple vector class with elements of type \a Base.
 
 \tparam VectorSet
-is either \c sparse_pack, \c sparse_set or \c sparse_list.
+is a simple vector class with elements of type 
+\c bool or \c std::set<size_t>.
 
-\param x
-See \c SparseHessian(x, w, p, row, col, hes, work).
+\tparam VectorSize
+is \c sparse_pack, \c sparse_set or \c sparse_list.
 
-\param w
-See \c SparseHessian(x, w, p, row, col, hes, work).
+\param x [in]
+is a vector specifing the point at which to compute the Hessian.
 
-\param sparsity
-If <code>work.color.size() != 0</code>, then \c sparsity is not used.
-Otherwise, it is a 
-sparsity pattern for the Hessian of this ADFun<Base> object.
+\param w [in]
+is the weighting vector that defines a scalar valued function by
+a weighted sum of the components of the vector valued function
+$latex F(x)$$.
 
-\param hes
-See \c SparseHessian(x, w, p, row, col, hes, work).
+\param sparsity [in]
+is the sparsity pattern for the Hessian that we are calculating.
+
+\param row [in]
+is the vector of row indices for the returned Hessian values.
+
+\param col [in]
+is the vector of columns indices for the returned Hessian values.
+It must have the same size are r.
+
+\param hes [out]
+is the vector of Hessian values.
+It must have the same size are r. 
+The return value <code>hes[k]</code> is the second partial of 
+\f$ w^{\rm T} F(x)\f$ with respect to the
+<code>row[k]</code> and <code>col[k]</code> component of \f$ x\f$.
 
 \param work
-See \c SparseHessian(x, w, p, row, col, hes, work).
+This structure contains information that is computed by \c SparseHessianCompute.
+If the sparsity pattern, \c row vector, or \c col vectors
+are not the same between calls to \c SparseHessianCompute, 
+\c work.clear() must be called to reinitialize \c work.
 
 \return
-See \c SparseHessian(x, w, p, row, col, hes, work).
+Is the number of first order forward sweeps used to compute the
+requested Hessian values.
+(This is also equal to the number of second order reverse sweeps.)
+The total work, not counting the zero order
+forward sweep, or the time to combine computations, is proportional to this
+return value.
 */
 template<class Base>
-template <class VectorBase, class VectorSet>
+template <class VectorBase, class VectorSet, class VectorSize>
 size_t ADFun<Base>::SparseHessianCompute(
-	const VectorBase&     x           ,
-	const VectorBase&     w           ,
-	VectorSet&            sparsity    ,
-	VectorBase&           hes         ,
-	sparse_hessian_work& work         )
+	const VectorBase&           x           ,
+	const VectorBase&           w           ,
+	      VectorSet&            sparsity    ,
+	const VectorSize&           row         ,
+	const VectorSize&           col         ,
+	      VectorBase&           hes         ,
+	      sparse_hessian_work&  work        )
 {
 	using   CppAD::vectorBool;
-	size_t i, j, k, ell;
+	size_t i, k, ell;
 
-	CppAD::vector<size_t>& row(work.r_sort);
-	CppAD::vector<size_t>& col(work.c_sort);
-	CppAD::vector<size_t>& user_k(work.k_sort);
 	CppAD::vector<size_t>& color(work.color);
+	CppAD::vector<size_t>& order(work.order);
 
 	size_t n = Domain();
 
@@ -338,13 +353,16 @@ size_t ADFun<Base>::SparseHessianCompute(
 
 	// number of components of Hessian that are required
 	size_t K = hes.size();
-	CPPAD_ASSERT_UNKNOWN( row.size() == K+1 );
+	CPPAD_ASSERT_UNKNOWN( row.size() == K );
 	CPPAD_ASSERT_UNKNOWN( col.size() == K );
-	CPPAD_ASSERT_UNKNOWN( row[K] == n );
 
 	// Point at which we are evaluating the Hessian
 	Forward(0, x);
 
+	// check for case where nothing (except Forward above) to do
+	if( K == 0 )
+		return 0;
+
 	// Rows of the Hessian (i below) correspond to the forward mode index
 	// and columns (j below) correspond to the reverse mode index.
 	if( color.size() == 0 )
@@ -352,100 +370,20 @@ size_t ADFun<Base>::SparseHessianCompute(
 		CPPAD_ASSERT_UNKNOWN( sparsity.n_set() ==  n );
 		CPPAD_ASSERT_UNKNOWN( sparsity.end() ==  n );
 
-		// rows and columns that are in the returned hessian
-		VectorSet r_used, c_used;
-		r_used.resize(n, n);
-		c_used.resize(n, n);
-		k = 0;
-		while( k < K )
-		{	CPPAD_ASSERT_UNKNOWN( row[k] < n && col[k] < n );
-			CPPAD_ASSERT_UNKNOWN( k == 0 || row[k-1] <= row[k] );
-			CPPAD_ASSERT_KNOWN(
-				sparsity.is_element(row[k], col[k]) ,
-				"SparseHessian: an (row, col) pair is not in sparsity pattern."
-			);
-			r_used.add_element(col[k], row[k]);
-			c_used.add_element(row[k], col[k]);
-			k++;
-		}
-	
-		// given a column index, which rows are non-zero and not used
-		VectorSet not_used;
-		not_used.resize(n, n);
-		for(i = 0; i < n; i++)
-		{	sparsity.begin(i);
-			j = sparsity.next_element();
-			while( j != sparsity.end() )
-			{	if( ! r_used.is_element(j , i) )
-					not_used.add_element(j, i);
-				j = sparsity.next_element();
-			}
-		}
-
-		// initial coloring
+		// execute coloring algorithm
 		color.resize(n);
-		for(i = 0; i < n; i++)
-			color[i] = i;
-	
-		// See GreedyPartialD2Coloring Algorithm Section 3.6.2 of
-		// Graph Coloring in Optimization Revisited by
-		// Assefaw Gebremedhin, Fredrik Maane, Alex Pothen
-		vectorBool forbidden(n);
-		for(i = 1; i < n; i++)
-		{
-			// initial all colors as ok for this row
-			// (value of forbidden for ell > i does not matter)
-			for(ell = 0; ell <= i; ell++)
-				forbidden[ell] = false;
-	
-			// -----------------------------------------------------
-			// Forbid colors that this row would destroy results for.
-			// for each column that is non-zero for this row
-			sparsity.begin(i);
-			j = sparsity.next_element();
-			while( j != sparsity.end() )
-			{	// for each row that this column uses
-				r_used.begin(j);
-				ell = r_used.next_element();
-				while( ell != r_used.end() )
-				{	// if this is not the same row, forbid its color
-					if( ell < i )
-						forbidden[ color[ell] ] = true;
-					ell = r_used.next_element();
-				}
-				j = sparsity.next_element();
-			}
-	
-			// -------------------------------------------------------
-			// Forbid colors that would destroy the results for this row.
-			// for each column that this row used
-			c_used.begin(i);
-			j = c_used.next_element();
-			while( j != c_used.end() )
-			{	// For each row that is non-zero for this column
-				// (the used rows have already been checked above).
-				not_used.begin(j);
-				ell = not_used.next_element();
-				while( ell != not_used.end() )
-				{	// if this is not the same row, forbid its color
-					if( ell < i )
-						forbidden[ color[ell] ] = true;
-					ell = not_used.next_element();
-				}
-				j = c_used.next_element();
-			}
+		color_general_cppad(sparsity, row, col, color);
+
+		// put sorting indices in color order
+		VectorSize key(K);
+		order.resize(K);
+		for(k = 0; k < K; k++)
+			key[k] = color[ row[k] ];
+		index_sort(key, order);
 
-			// pick the color with the smallest index
-			ell = 0;
-			while( forbidden[ell] )
-			{	ell++;
-				CPPAD_ASSERT_UNKNOWN( ell <= i );
-			}
-			color[i] = ell;
-		}
 	}
 	size_t n_color = 1;
-	for(ell = 0; ell < n; ell++) 
+	for(ell = 0; ell < n; ell++) if( color[ell] < n )
 		n_color = std::max(n_color, color[ell] + 1);
 
 	// direction vector for calls to forward (rows of the Hessian)
@@ -459,387 +397,29 @@ size_t ADFun<Base>::SparseHessianCompute(
 		hes[k] = zero;
 
 	// loop over colors
-	size_t n_sweep = 0;
+	k = 0;
 	for(ell = 0; ell < n_color; ell++)
-	{	bool any = false;
-		k = 0;
-		for(i = 0; i < n; i++) if( color[i] == ell )
-		{	// find first k such that row[k] has color ell
-			if( ! any )
-			{	while( row[k] < i )
-					k++;
-				any = row[k] == i;
-			}
+	{	CPPAD_ASSERT_UNKNOWN( color[ row[ order[k] ] ] == ell );
+
+		// combine all rows with this color
+		for(i = 0; i < n; i++)
+		{	u[i] = zero;
+			if( color[i] == ell )
+				u[i] = one;
 		}
-		if( any )
-		{	n_sweep++;
-			// combine all rows with this color
-			for(i = 0; i < n; i++)
-			{	u[i] = zero;
-				if( color[i] == ell )
-					u[i] = one;
-			}
-			// call forward mode for all these rows at once
-			Forward(1, u);
+		// call forward mode for all these rows at once
+		Forward(1, u);
 
-			// evaluate derivative of w^T * F'(x) * u
-			ddw = Reverse(2, w);
+		// evaluate derivative of w^T * F'(x) * u
+		ddw = Reverse(2, w);
 
-			// set the corresponding components of the result
-			for(i = 0; i < n; i++) if( color[i] == ell )
-			{	// find first index in c for this column
-				while( row[k] < i )
-					k++;
-				// extract the results for this row
-				while( row[k] == i ) 
-				{	hes[ user_k[k] ] = ddw[ col[k] * 2 + 1 ];
-					k++;
-				}
-			}
-		}
-	}
-	return n_sweep;
-}
-// ===========================================================================
-/*!
-Private helper function for vector of \c bool sparsity pattern cases.
-
-\tparam Base
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\tparam VectorBase
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\tparam VectorSet
-is a simple vector with elements of type \c bool.
-
-\param set_type
-has element type for vector representing the sparsity sets.
-
-\param x
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\param w
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\param p
-Sparsity pattern for the Hessian of this ADFun<Base> object.
-
-\param hes
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\param work
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\return
-See \c SparseHessian(x, w, p, row, col, hes, work).
-*/
-template <class Base>
-template <class VectorBase, class VectorSet>
-size_t ADFun<Base>::SparseHessianCase(
-	bool                  set_type  ,
-	const VectorBase&     x         ,
-	const VectorBase&     w         ,
-	const VectorSet&      p         ,
-	VectorBase&           hes       ,
-	sparse_hessian_work&  work      )
-{
-	size_t n = Domain();
-
-	// check VectorSet is Simple Vector class with bool elements
-	CheckSimpleVector<bool, VectorSet>();
-
-	// check VectorBase is Simple Vector class with Base type elements
-	CheckSimpleVector<Base, VectorBase>();
-
-	CPPAD_ASSERT_UNKNOWN( size_t(x.size()) == n );
-	CPPAD_ASSERT_UNKNOWN( size_t(w.size()) == Range() );
-	CPPAD_ASSERT_KNOWN(
-		size_t(p.size()) == n * n,
-		"SparseHessian: using bool values for sparsity and p.size() "
-		"not equal square of domain dimension for f"
-	);
- 
-	sparse_pack sparsity;
-	if( work.color.size() == 0 )
-	{	bool transpose = false;
-		sparsity_user2internal(sparsity, p, n, n, transpose);
-	}
-	
-	// compute the Hessian
-	size_t n_sweep = SparseHessianCompute(x, w, sparsity, hes, work);
-
-	return n_sweep;
-}
-/*!
-Private helper function for vector of std::set<size_t> sparsity pattern cases.
-
-\tparam Base
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\tparam VectorBase
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\tparam VectorSet
-is a simple vector with elements of type <code>std::set<size_t></code>.
-
-\param set_type
-has element type for vector representing the sparsity sets.
-
-\param x
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\param w
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\param p
-Sparsity pattern for the Hessian of this ADFun<Base> object.
-
-\param hes
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\param work
-See \c SparseHessian(x, w, p, row, col, hes, work).
-
-\return
-See \c SparseHessian(x, w, p, row, col, hes, work).
-*/
-template <class Base>
-template <class VectorBase, class VectorSet>
-size_t ADFun<Base>::SparseHessianCase(
-	const std::set<size_t>&     set_type  ,
-	const VectorBase&           x         ,
-	const VectorBase&           w         ,
-	const VectorSet&            p         ,
-	VectorBase&                 hes       ,
-	sparse_hessian_work&        work      )
-{
-	size_t n = Domain();
-
-	// check VectorSet is Simple Vector class with std::set<size_t> elements
-	CheckSimpleVector<std::set<size_t>, VectorSet>(
-		one_element_std_set<size_t>(), two_element_std_set<size_t>()
-	);
-
-	// check VectorBase is Simple Vector class with Base type elements
-	CheckSimpleVector<Base, VectorBase>();
-
-	CPPAD_ASSERT_UNKNOWN( size_t(x.size()) == n );
-	CPPAD_ASSERT_UNKNOWN( size_t(w.size()) == Range() );
-	CPPAD_ASSERT_KNOWN(
-		size_t(p.size()) == n,
-		"SparseHessian: using std::set<size_t> for sparsity and p.size() "
-		"not equal domain dimension for f"
-	);
- 
-	CPPAD_INTERNAL_SPARSE_SET sparsity;
-	if( work.color.size() == 0 )
-	{	bool transpose = false;
-		sparsity_user2internal(sparsity, p, n, n, transpose);
-	}
-	
-	// compute the Hessian
-	size_t n_sweep = SparseHessianCompute(x, w, sparsity, hes, work);
-
-	return n_sweep;
-}
-// ===========================================================================
-/*!
-Private helper function for SparseHessian(x, w, p).
-
-All of the description in the public member function SparseHessian(x, w, p)
-applies.
-
-\param set_type
-is a \c bool value. This argument is used to dispatch to the proper source
-code depending on the value of \c VectorSet::value_type.
-
-\param x
-See \c SparseHessian(x, w, p).
-
-\param w
-See \c SparseHessian(x, w, p).
-
-\param p
-See \c SparseHessian(x, w, p).
-
-\param hes
-is the return value for the corresponding call to \c SparseHessian(x, w, p).
-On input, it must have size equal to the domain times range dimension
-for this ADFun<Base> object.
-On return, it will contain the Hessian.
-*/
-
-template <class Base>
-template <class VectorBase, class VectorSet>
-void ADFun<Base>::SparseHessianCase(
-	bool               set_type         ,
-	const VectorBase&  x                ,
-	const VectorBase&  w                ,
-	const VectorSet&   p                ,
-	VectorBase&        hes              )
-{
-	size_t n = Domain();
-	size_t i, j, k;
-
-	// check Vector is Simple Vector class with bool elements
-	CheckSimpleVector<bool, VectorSet>();
-
-	// check Vector is Simple Vector class with Base type elements
-	CheckSimpleVector<Base, VectorBase>();
-
-	CPPAD_ASSERT_KNOWN(
-		size_t(x.size()) == n,
-		"SparseHessian: size of x not equal domain dimension for f"
-	); 
-	CPPAD_ASSERT_KNOWN(
-		size_t(w.size()) == Range(),
-		"SparseHessian: size of w not equal range dimension for f"
-	);
-	CPPAD_ASSERT_KNOWN(
-		size_t(p.size()) == n * n,
-		"SparseHessian: using bool values and size of p "
-		"not equal square of domain dimension for f"
-	);
-	sparse_hessian_work work;
-	CppAD::vector<size_t>& row(work.r_sort);
-	CppAD::vector<size_t>& col(work.c_sort);
-	CppAD::vector<size_t>& user_k(work.k_sort);
-
-	k = 0;
-	for(i = 0; i < n; i++)
-	{	for(j = 0; j < n; j++)
-			if( p[i * n + j] )
-				k++;
-	}
-	size_t K = k;
-	VectorBase H(K);
-	row.resize(K+1);
-	col.resize(K);
-	user_k.resize(K);
-	k = 0;
-	for(i = 0; i < n; i++)
-	{	for(j = 0; j < n; j++)
-			if( p[i * n + j] )
-			{	row[k]      = i;
-				col[k]      = j;
-				user_k[k] = k;  
-				k++;
-			}
-	}
-	row[K] = n;
- 
-	SparseHessianCase(set_type, x, w, p, H, work);
-
-	Base zero(0);
-	for(i = 0; i < n; i++)
-	{	for(j = 0; j < n; j++)
-			hes[i * n + j] = zero; 
-	}
-	for(k = 0; k < K; k++)
-		hes[row[k] * n + col[k]] = H[k]; 
-}
-/*!
-Private helper function for SparseHessian(x, w, p).
-
-All of the description in the public member function SparseHessian(x, w, p)
-applies.
-
-\param set_type
-is a \c std::set<size_t> value.
-This argument is used to dispatch to the proper source
-code depending on the value of \c VectorSet::value_type.
-
-\param x
-See \c SparseHessian(x, w, p).
-
-\param w
-See \c SparseHessian(x, w, p).
-
-\param p
-See \c SparseHessian(x, w, p).
-
-\param hes
-is the return value for the corresponding call to \c SparseHessian(x, w, p).
-On input, it must have size equal to the domain times range dimension
-for this ADFun<Base> object.
-On return, it will contain the Hessian.
-*/
-
-template <class Base>
-template <class VectorBase, class VectorSet>
-void ADFun<Base>::SparseHessianCase(
-	const std::set<size_t>&  set_type         ,
-	const VectorBase&        x                ,
-	const VectorBase&        w                ,
-	const VectorSet&         p                ,
-	VectorBase&              hes              )
-{
-	size_t n = Domain();
-	size_t i, j, k;
-
-	// check VectorSet is Simple Vector class with sets for elements
-	CheckSimpleVector<std::set<size_t>, VectorSet>(
-		one_element_std_set<size_t>(), two_element_std_set<size_t>()
-	);
-
-	// check Vector is Simple Vector class with Base type elements
-	CheckSimpleVector<Base, VectorBase>();
-
-	CPPAD_ASSERT_KNOWN(
-		size_t(x.size()) == n,
-		"SparseHessian: size of x not equal domain dimension for f"
-	); 
-	CPPAD_ASSERT_KNOWN(
-		size_t(w.size()) == Range(),
-		"SparseHessian: size of w not equal range dimension for f"
-	);
-	CPPAD_ASSERT_KNOWN(
-		size_t(p.size()) == n,
-		"SparseHessian: using size_t sets for sparsity pattern and p.size() "
-		"not equal domain dimension for f"
-	);
-	sparse_hessian_work work;
-	CppAD::vector<size_t>& row(work.r_sort);
-	CppAD::vector<size_t>& col(work.c_sort);
-	CppAD::vector<size_t>& user_k(work.k_sort);
-
-	k = 0;
-	std::set<size_t>::const_iterator itr;
-	for(i = 0; i < n; i++)
-	{	itr = p[i].begin();
-		while( itr != p[i].end() )
-		{	itr++;
+		// set the corresponding components of the result
+		while( k < K && color[ row[ order[k] ] ] == ell ) 
+		{	hes[ order[k] ] = ddw[ col[ order[k] ] * 2 + 1 ];
 			k++;
 		}
 	}
-	size_t K = k;
-	VectorBase H(K);
-	row.resize(K+1);
-	col.resize(K);
-	user_k.resize(K);
-	k = 0;
-	for(i = 0; i < n; i++)
-	{ 	itr = p[i].begin();
-		while( itr != p[i].end() )
-		{	row[k]      = i;
-			col[k]      = *itr;
-			user_k[k] = k;  
-			itr++;
-			k++;
-		}
-	}
-	row[K] = n;
- 
-	SparseHessianCase(set_type, x, w, p, H, work);
-
-	Base zero(0);
-	for(i = 0; i < n; i++)
-	{	for(j = 0; j < n; j++)
-			hes[i * n + j] = zero; 
-	}
-	for(k = 0; k < K; k++)
-		hes[row[k] * n + col[k]] = H[k]; 
+	return n_color;
 }
 // ===========================================================================
 // Public Member Functions
@@ -865,25 +445,25 @@ is a simple vector class with elements of type
 \tparam VectorSize
 is a simple vector class with elements of type \c size_t.
 
-\param x
+\param x [in]
 is a vector specifing the point at which to compute the Hessian.
 
-\param w
+\param w [in]
 is the weighting vector that defines a scalar valued function by
 a weighted sum of the components of the vector valued function
 $latex F(x)$$.
 
-\param p
+\param p [in]
 is the sparsity pattern for the Hessian that we are calculating.
 
-\param row
+\param row [in]
 is the vector of row indices for the returned Hessian values.
 
-\param col
+\param col [in]
 is the vector of columns indices for the returned Hessian values.
 It must have the same size are r.
 
-\param hes
+\param hes [out]
 is the vector of Hessian values.
 It must have the same size are r. 
 The return value <code>hes[k]</code> is the second partial of 
@@ -891,20 +471,10 @@ The return value <code>hes[k]</code> is the second partial of
 <code>row[k]</code> and <code>col[k]</code> component of \f$ x\f$.
 
 \param work
-contains information that depends on the function object, sparsity pattern,
-\c row, and \c col vector.
-If these values are the same, \c work does not need to be recomputed.
-To be more specific, 
-\c r_sort is sorted copy of \c row ,
-\c c_sort is sorted copy of \c col ,
-<code>k_sort[k]</code> is the original index corresponding to the
-values <code>r_sort[k]</code> and <code>c_sort[k]</code>.
-The order for the sort is by columns.
-Let \c n the domain dimension,
-and \c K the size of \c row , \c col , and \c hes.
-There is one extra entry 
-in the sorted row array and it has value <code>r_sort[K]=n</code>.
-The \c color vector is set and used by \c SparseHessianCompute.
+This structure contains information that is computed by \c SparseHessianCompute.
+If the sparsity pattern, \c row vector, or \c col vectors
+are not the same between calls to \c SparseHessian, 
+\c work.clear() must be called to reinitialize \c work.
 
 \return
 Is the number of first order forward sweeps used to compute the
@@ -925,24 +495,9 @@ size_t ADFun<Base>::SparseHessian(
 	VectorBase&           hes  ,
 	sparse_hessian_work&  work )
 {
-	size_t n = Domain();
-	size_t k, K = hes.size();
-	if( work.r_sort.size() == 0 )
-	{	// create version of (row, col, k) sorted by row value
-		work.c_sort.resize(K);
-		work.r_sort.resize(K+1);
-		work.k_sort.resize(K);
-
-		// put sorting indices in k_sort
-		index_sort(row, work.k_sort);
-
-		for(k = 0; k < K; k++)
-		{	work.r_sort[k] = row[ work.k_sort[k] ];
-			work.c_sort[k] = col[ work.k_sort[k] ];
-		}
-		work.r_sort[K] = n;
-	}
+	size_t n    = Domain();
 # ifndef NDEBUG
+	size_t k, K = hes.size();
 	CPPAD_ASSERT_KNOWN(
 		size_t(x.size()) == n ,
 		"SparseHessian: size of x not equal domain dimension for f."
@@ -951,12 +506,6 @@ size_t ADFun<Base>::SparseHessian(
 		size_t(row.size()) == K && size_t(col.size()) == K ,
 		"SparseHessian: either r or c does not have the same size as ehs."
 	); 
-	CPPAD_ASSERT_KNOWN(
-		work.r_sort.size() == K+1 &&
-		work.c_sort.size() == K   &&
-		work.k_sort.size() == K   ,
-		"SparseHessian: invalid value in work."
-	);
 	CPPAD_ASSERT_KNOWN(
 		work.color.size() == 0 || work.color.size() == n,
 		"SparseHessian: invalid value in work."
@@ -970,28 +519,21 @@ size_t ADFun<Base>::SparseHessian(
 			col[k] < n,
 			"SparseHessian: invalid value in c."
 		);
-		CPPAD_ASSERT_KNOWN(
-			work.k_sort[k] < K,
-			"SparseHessian: invalid value in work."
-		);
-		CPPAD_ASSERT_KNOWN(
-			work.r_sort[k] == row[ work.k_sort[k] ] ,
-			"SparseHessian: invalid value in work."
-		);
-		CPPAD_ASSERT_KNOWN(
-			work.c_sort[k] == col[ work.k_sort[k] ],
-			"SparseHessian: invalid value in work."
-		);
 	}
 	if( work.color.size() != 0 )
 		for(size_t j = 0; j < n; j++) CPPAD_ASSERT_KNOWN(
-			work.color[j] < n,
+			work.color[j] <= n,
 			"SparseHessian: invalid value in work."
 	);
 # endif
- 
 	typedef typename VectorSet::value_type Set_type;
-	size_t n_sweep = SparseHessianCase(Set_type(), x, w, p, hes, work);
+	typedef typename internal_sparsity<Set_type>::pattern_type Pattern_type;
+	Pattern_type s;
+	if( work.color.size() == 0 )
+	{	bool transpose = false;
+		sparsity_user2internal(s, p, n, n, transpose);
+	}
+	size_t n_sweep = SparseHessianCompute(x, w, s, row, col, hes, work);
 	return n_sweep;
 }
 /*!
@@ -1014,16 +556,16 @@ is a simple vector class with elements of the \a Base.
 is a simple vector class with elements of type
 \c bool or \c std::set<size_t>.
 
-\param x
+\param x [in]
 is a vector specifing the point at which to compute the Hessian.
 
-\param w
+\param w [in]
 The Hessian is computed for a weighted sum of the components
 of the function corresponding to this ADFun<Base> object.
 The argument \a w specifies the weights for each component.
 It must have size equal to the range dimension for this ADFun<Base> object.
 
-\param p
+\param p [in]
 is a sparsity pattern for the Hessian.
 
 \return
@@ -1036,11 +578,52 @@ template <class VectorBase, class VectorSet>
 VectorBase ADFun<Base>::SparseHessian(
 	const VectorBase& x, const VectorBase& w, const VectorSet& p
 )
-{	size_t n = Domain();
+{	size_t i, j, k;
+
+	size_t n = Domain();
 	VectorBase hes(n * n);
 
+	CPPAD_ASSERT_KNOWN(
+		size_t(x.size()) == n,
+		"SparseHessian: size of x not equal domain size for f."
+	);
+
 	typedef typename VectorSet::value_type Set_type;
-	SparseHessianCase(Set_type(), x, w, p, hes);
+	typedef typename internal_sparsity<Set_type>::pattern_type Pattern_type;
+
+	// initialize the return value as zero
+	Base zero(0);
+	for(i = 0; i < n; i++)
+		for(j = 0; j < n; j++)
+			hes[i * n + j] = zero;
+
+	// arguments to SparseHessianCompute
+	Pattern_type          s;
+	CppAD::vector<size_t> row;
+	CppAD::vector<size_t> col; 
+	sparse_hessian_work   work;
+	bool transpose = false;
+	sparsity_user2internal(s, p, n, n, transpose);
+	k = 0;
+	for(i = 0; i < n; i++)
+	{	s.begin(i);
+		j = s.next_element();
+		while( j != s.end() )
+		{	row.push_back(i);
+			col.push_back(j);
+			k++;
+			j = s.next_element();
+		}
+	}
+	size_t K = k;
+	VectorBase H(K);
+
+	// now we have folded this into the following case
+	SparseHessianCompute(x, w, s, row, col, H, work);
+
+	// now set the non-zero return values
+	for(k = 0; k < K; k++)
+		hes[ row[k] * n + col[k] ] = H[k];
 
 	return hes;
 }
@@ -1060,10 +643,10 @@ ADFun<Base object.
 \tparam VectorBase
 is a simple vector class with elements of the \a Base.
 
-\param x
+\param x [in]
 is a vector specifing the point at which to compute the Hessian.
 
-\param w
+\param w [in]
 The Hessian is computed for a weighted sum of the components
 of the function corresponding to this ADFun<Base> object.
 The argument \a w specifies the weights for each component.
@@ -1098,13 +681,8 @@ VectorBase ADFun<Base>::SparseHessian(const VectorBase &x, const VectorBase &w)
 	VectorBool p = RevSparseHes(n, s);
 
 	// compute sparse Hessian
-	VectorBase hes(n * n);
-	bool set_type = true; // only used to dispatch compiler to proper case
-	SparseHessianCase(set_type, x, w, p, hes);
-
-	return hes;
+	return SparseHessian(x, w, p);
 }
 
-/*! \} */
 } // END_CPPAD_NAMESPACE
 # endif
