@@ -1,4 +1,4 @@
-/* $Id: optimize.cpp 3507 2014-12-27 16:30:12Z bradbell $ */
+/* $Id: optimize.cpp 3643 2015-02-12 11:47:46Z bradbell $ */
 /* --------------------------------------------------------------------------
 CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
 
@@ -401,7 +401,7 @@ namespace {
 		y = F.Forward(0, x);
 		depend_fun(x, check, original, opt);
 		for(i = 0; i < m; i++)
-			ok &= (y[i] == check[i]);
+			ok &= CppAD::NearEqual(y[i], check[i], 1e-10, 1e-10);
 	
 		// Check size before optimization
 		ok &= F.size_var() == (n + 1 + original);
@@ -416,7 +416,7 @@ namespace {
 		// (should have already been checked if NDEBUG not defined)
 		y = F.Forward(0, x);
 		for(i = 0; i < m; i++)
-			ok &= (y[i] == check[i]);
+			ok &= CppAD::NearEqual(y[i], check[i], 1e-10, 1e-10);
 	
 		return ok;
 	}
@@ -545,6 +545,35 @@ namespace {
 	
 		return ok;
 	}
+	bool depend_four(void)
+	{	// erf function is a special case for optimize
+		bool ok = true;
+# if CPPAD_COMPILER_HAS_ERF
+		using CppAD::AD;
+		using CppAD::vector;
+
+		size_t n = 1;
+		size_t m = 1;
+		vector< AD<double> > X(n), Y(m);
+		vector<double>       x(n);
+		X[0] = x[0] = double(0.5);
+
+		CppAD::Independent(X);
+
+		Y[0] = erf(X[0]) + erf(X[0]);
+
+		CppAD::ADFun<double> F(X, Y);
+
+		vector<double> y_original     = F.Forward(0, x);
+		size_t         size_original  = F.size_var();
+		F.optimize();
+		// version 20150000 does not remove duplicate erf function calls.
+		ok &= F.size_var() == size_original;
+		vector<double> y = F.Forward(0, x);
+		ok &=  CppAD::NearEqual(y[0], y_original[0], 1e-10, 1e-10);
+# endif
+		return ok;
+	}
 	// ===================================================================
 	// Test duplicate operation analysis
 
@@ -650,7 +679,7 @@ namespace {
 		y = F.Forward(0, x);
 		duplicate_fun(x, check, original, opt);
 		for(i = 0; i < m; i++)
-			ok &= (y[i] == check[i]);
+			ok &= CppAD::NearEqual(y[i], check[i], 1e-10, 1e-10);
 	
 		// Check size before optimization
 		ok &= F.size_var() == (n + 1 + original);
@@ -665,7 +694,7 @@ namespace {
 		// (should have already been checked if NDEBUG not defined)
 		y = F.Forward(0, x);
 		for(i = 0; i < m; i++)
-			ok &= (y[i] == check[i]);
+			ok &= CppAD::NearEqual(y[i], check[i], 1e-10, 1e-10);
 	
 		return ok;
 	}
@@ -1258,6 +1287,40 @@ namespace {
 
 		return ok;
 	}
+	// check that CondExp properly handels expressions that get 
+	// removed during opitmization
+	bool cond_exp_removed(void)
+	{	bool ok = true;
+		using CppAD::AD;
+		AD<double> zero(0.);
+	
+		size_t n = 1;
+		CppAD::vector< AD<double> > X(n); 
+		X[0] = 1.0;
+		CppAD::Independent(X);
+	
+		size_t m = 1;
+		CppAD::vector< AD<double> > Y(m);
+
+		AD<double> true_case  = sin(X[0]) + sin(X[0]);
+		AD<double> false_case = cos(X[0]) + cos(X[0]);
+		Y[0] = CondExpLt(X[0],  zero,  true_case, false_case);
+
+		CppAD::ADFun<double> f(X, Y);
+		f.optimize();
+
+		CppAD::vector<double> x(n), y(m), w(m), dw(n);
+		x[0] = 1.0;
+		y    = f.Forward(0, x);
+		ok &= NearEqual(y[0], false_case, 1e-10, 1e-10);
+
+		w[0] = 1.0;
+		dw   = f.Reverse(1, w);
+		// derivative of cos is minus sin
+		ok &= NearEqual(dw[0], - true_case, 1e-10, 1e-10);
+
+		return ok;
+	}
 	// -------------------------------------------------------------------
 	void my_union(
 		std::set<size_t>&         result  ,
@@ -1651,6 +1714,7 @@ bool optimize(void)
 	ok     &= depend_one();
 	ok     &= depend_two();
 	ok     &= depend_three();
+	ok     &= depend_four();
 	// check removal of duplicate expressions
 	ok     &= duplicate_one();
 	ok     &= duplicate_two();
@@ -1666,6 +1730,8 @@ bool optimize(void)
 	ok     &= reverse_sparse_hessian();
 	// check that CondExp properly detects dependencies
 	ok     &= cond_exp_depend();
+	// check that CondExp properly handles expressions that are removed
+	ok     &= cond_exp_removed();
 	// check old_atomic functions
 	ok     &= old_atomic_test();
 	// case where results are not identically equal
